@@ -17,45 +17,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _CHEESE_EFFECT_H_
-#define _CHEESE_EFFECT_H_
+#ifndef CHEESE_EFFECT_H_
+#define CHEESE_EFFECT_H_
 
 #include <glib-object.h>
 
 G_BEGIN_DECLS
 
-#define CHEESE_TYPE_EFFECT cheese_effect_get_type ()
-
-#define CHEESE_EFFECT(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), CHEESE_TYPE_EFFECT, CheeseEffect))
-
-#define CHEESE_EFFECT_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), CHEESE_TYPE_EFFECT, CheeseEffectClass))
-
-#define CHEESE_IS_EFFECT(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CHEESE_TYPE_EFFECT))
-
-#define CHEESE_IS_EFFECT_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), CHEESE_TYPE_EFFECT))
-
-#define CHEESE_EFFECT_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), CHEESE_TYPE_EFFECT, CheeseEffectClass))
-
-typedef struct _CheeseEffectPrivate CheeseEffectPrivate;
-typedef struct _CheeseEffectClass CheeseEffectClass;
-typedef struct _CheeseEffect CheeseEffect;
-
-/**
- * CheeseEffectClass:
- *
- * Use the accessor functions below.
- */
-struct _CheeseEffectClass
-{
-  /*< private >*/
-  GObjectClass parent_class;
-};
-
 /**
  * CheeseEffect:
  *
@@ -68,7 +36,8 @@ struct _CheeseEffect
   void *unused;
 };
 
-GType cheese_effect_get_type (void);
+#define CHEESE_TYPE_EFFECT cheese_effect_get_type ()
+G_DECLARE_FINAL_TYPE (CheeseEffect, cheese_effect, CHEESE, EFFECT, GObject)
 
 CheeseEffect *cheese_effect_new (const gchar *name,
                                  const gchar *pipeline_desc);
@@ -83,4 +52,4 @@ GList        *cheese_effect_load_effects (void);
 
 G_END_DECLS
 
-#endif /* _CHEESE_EFFECT_H_ */
+#endif /* CHEESE_EFFECT_H_ */
